Welcome to Zucchini's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 3

   readme
   installation
   usage

   config-files
   config-samples/index

   architecture/index

   modules
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
